@@ -2,12 +2,12 @@ use crate::extensions::server::ServerExtension;
 
 use crate::parse_buffer::ParseBuffer;
 use crate::TlsError;
-use heapless::{consts::*, Vec};
+use heapless::Vec;
 
 #[derive(Debug)]
 #[cfg_attr(feature = "defmt", derive(defmt::Format))]
 pub struct EncryptedExtensions<'a> {
-    extensions: Vec<ServerExtension<'a>, U16>,
+    extensions: Vec<ServerExtension<'a>, 16>,
 }
 
 impl<'a> EncryptedExtensions<'a> {
